@@ -6,7 +6,7 @@ from copy import copy
 from typing import List, Optional, Union
 import scipp as sc
 from .nxobject import NXobject, Field, ScippIndex, NexusStructureError
-from .nxobject import is_dataset, asarray
+from .nxobject import is_dataset
 from .nxdata import NXdata
 from .nxevent_data import NXevent_data
 
@@ -91,7 +91,9 @@ class _EventField:
                                  stop=id_max.value + 1,
                                  dtype=id_min.dtype)
         else:
-            grouping = asarray(self._grouping[select])
+            grouping = self._grouping[select]
+            if not isinstance(grouping, sc.Variable):
+                grouping = sc.scalar(grouping, unit=None, dtype=self._grouping.dtype)
             if (self._grouping_key in event_data.coords) and sc.identical(
                     grouping, event_data.coords[self._grouping_key]):
                 return event_data
