@@ -22,6 +22,10 @@ from ._common import convert_time_to_datetime64
 NXobjectIndex = Union[str, ScippIndex]
 
 
+def asarray(obj: Union[Any, sc.Variable]) -> sc.Variable:
+    return obj if isinstance(obj, sc.Variable) else sc.scalar(obj, unit=None)
+
+
 # TODO move into scipp
 class DimensionedArray(Protocol):
     """
@@ -157,7 +161,12 @@ class Field:
             self._shape = [size for size in self._shape if size != 1]
             self._dims = [f'dim_{i}' for i in range(self.ndim)]
 
-    def __getitem__(self, select) -> sc.Variable:
+    def __getitem__(self, select) -> Union[Any, sc.Variable]:
+        """Load the field as a :py:class:`scipp.Variable` or Python object.
+
+        If the shape is empty and no unit is given this returns a Python object, such
+        as a string or integer. Otherwise a :py:class:`scipp.Variable` is returned.
+        """
         index = to_plain_index(self.dims, select)
         if isinstance(index, (int, slice)):
             index = (index, )
@@ -212,6 +221,8 @@ class Field:
                     variable,
                     start=starts[0],
                     scaling_factor=self.attrs.get('scaling_factor'))
+        if variable.ndim == 0 and variable.unit is None:
+            return variable.value
         return variable
 
     def __repr__(self) -> str:
@@ -311,13 +322,20 @@ class NXobject:
                 return _make(item)
         da = self._getitem(name)
         if (t := self.depends_on) is not None:
-            da.coords['depends_on'] = t if isinstance(t, sc.Variable) else sc.scalar(t)
+            if isinstance(da, dict):
+                da['depends_on'] = t
+            else:
+                da.coords['depends_on'] = t if isinstance(t,
+                                                          sc.Variable) else sc.scalar(t)
         return da
 
-    def _get_children_by_nx_class(self, select: type) -> Dict[str, 'NXobject']:
+    def _get_children_by_nx_class(
+            self, select: Union[type,
+                                List[type]]) -> Dict[str, Union['NXobject', Field]]:
         children = {}
+        select = tuple(select) if isinstance(select, list) else select
         for key in self.keys():
-            if (child := self._get_child(key)).attrs.get('NX_class') == select.__name__:
+            if issubclass(type(child := self._get_child(key)), select):
                 children[key] = child
         return children
 
@@ -330,7 +348,7 @@ class NXobject:
         ...
 
     @overload
-    def __getitem__(self, name: type) -> Dict[str, 'NXobject']:
+    def __getitem__(self, name: Union[type, Tuple[type]]) -> Dict[str, 'NXobject']:
         ...
 
     def __getitem__(self, name):
@@ -342,7 +360,9 @@ class NXobject:
 
         - String name: The child group or child dataset of that name is returned.
         - Class such as ``NXdata`` or ``NXlog``: A dict containing all direct children
-          with a matching ``NX_class`` attribute are returned.
+          with a matching ``NX_class`` attribute are returned. Also accepts a tuple of
+          classes. ``Field`` selects all child fields, i.e., all datasets but not
+          groups.
         - Scipp-style index: Load the specified slice of the current group, returning
           a :class:`scipp.DataArray` or :class:`scipp.Dataset`.
 
@@ -356,7 +376,12 @@ class NXobject:
         :
             Field, group, dict of fields, or loaded data.
         """
-        if inspect.isclass(name) and issubclass(name, NXobject):
+
+        def isclass(x):
+            return inspect.isclass(x) and issubclass(x, (Field, NXobject))
+
+        if isclass(name) or (isinstance(name, list) and len(name)
+                             and all(isclass(x) for x in name)):
             return self._get_children_by_nx_class(name)
         return self._get_child(name, use_field_dims=True)
 
